@@ -1,6 +1,6 @@
-use crate::extractor::Value;
 use crate::filter::Filter;
 use crate::state::StateManager;
+use crate::Value;
 
 pub struct CountStateFilter {
     state_index: u32,
@@ -9,7 +9,10 @@ pub struct CountStateFilter {
 
 impl CountStateFilter {
     pub fn new(state_index: u32, required_state: u32) -> Self {
-        Self { state_index, required_state }
+        Self {
+            state_index,
+            required_state,
+        }
     }
 }
 
@@ -25,13 +28,15 @@ impl Filter for CountStateFilter {
         let current_state = state_manager.get_value(self.state_index);
 
         let current_state = match current_state {
-            Value::U32(value) => value,
+            Value::U32(value) => value + 1,
             _ => {
                 panic!("Wrong state value provided for count state filter.");
             }
         };
 
-        if *current_state == self.required_state {
+        state_manager.set_value(self.state_index, Value::U32(current_state));
+
+        if current_state == self.required_state {
             state_manager.set_value(self.state_index, Value::U32(0));
             true
         } else {
