@@ -1,9 +1,9 @@
 use ross_protocol::packet::Packet;
 
-use crate::DeviceInfo;
-use crate::extractor::Value;
 use crate::producer::Producer;
 use crate::state::StateManager;
+use crate::DeviceInfo;
+use crate::Value;
 
 pub struct NoneProducer {}
 
@@ -14,7 +14,12 @@ impl NoneProducer {
 }
 
 impl Producer for NoneProducer {
-    fn produce(&self, _value: &Value, _device_info: &DeviceInfo, _state_manager: &StateManager) -> Option<Packet> {
+    fn produce(
+        &self,
+        _value: &Value,
+        _device_info: &DeviceInfo,
+        _state_manager: &StateManager,
+    ) -> Option<Packet> {
         None
     }
 }
